@@ -70,7 +70,7 @@ get_base_format = function(format, options = list()) {
 }
 
 load_config = function(config_file = '_bookdown.yml') {
-  config_file = opts$get('config_file') %n% config_file
+  config_file = opts$get('config_file') %||% config_file
   if (length(opts$get('config')) == 0 && file.exists(config_file)) {
     # store the book config
     opts$set(config = rmarkdown:::yaml_load_file(config_file))
@@ -86,12 +86,13 @@ book_filename = function(config = load_config(), fallback = TRUE) {
 
 source_files = function(format = NULL, config = load_config(), all = FALSE) {
   subdir = config[['rmd_subdir']]; subdir_yes = isTRUE(subdir) || is.character(subdir)
+  ext_regex = if (isTRUE(config[['include_md']])) '[.]R?md$' else '[.]Rmd$'
   # a list of Rmd chapters
-  files = list.files('.', '[.]Rmd$', ignore.case = TRUE)
+  files = list.files('.', ext_regex, ignore.case = TRUE)
   # content in subdir if asked
   subdir_files = unlist(mapply(
     list.files,
-    if (is.character(subdir)) subdir else '.', '[.]Rmd$', ignore.case = TRUE,
+    if (is.character(subdir)) subdir else '.', ext_regex, ignore.case = TRUE,
     recursive = subdir_yes, full.names = is.character(subdir), USE.NAMES = FALSE
   ))
   subdir_files = setdiff(subdir_files, files)
@@ -263,7 +264,7 @@ clean_meta = function(meta_file, files) {
 
 # remove HTML tags and remove extra spaces
 strip_html = function(x) {
-  gsub('\\s{2,}', ' ', xfun::strip_html(x))
+  gsub('\\s{2,}', ' ', xfun::strip_html(x), perl = TRUE)
 }
 
 # remove the <script><script> content and references
@@ -457,19 +458,6 @@ files_cache_dirs = function(dir = '.') {
   out
 }
 
-# file.rename() does not work if target directory is not empty, so we just copy
-# everything from `from` to `to`, and delete `from`
-move_dir = function(from, to) {
-  if (!dir_exists(to)) return(file.rename(from, to))
-  to_copy = list.files(from, full.names = TRUE)
-  if (length(to_copy) == 0 ||
-      any(file.copy(list.files(from, full.names = TRUE), to, recursive = TRUE))
-  ) unlink(from, recursive = TRUE)
-  invisible(TRUE)
-}
-
-move_dirs = function(from, to) mapply(move_dir, from, to)
-
 #' @importFrom xfun existing_files
 existing_r = function(base) {
   x = apply(expand.grid(base, c('R', 'r')), 1, paste, collapse = '.')
@@ -502,7 +490,7 @@ verify_rstudio_version = function() {
 
 str_trim = function(x) gsub('^\\s+|\\s+$', '', x)
 
-`%n%` = knitr:::`%n%`
+if (getRversion() < '4.4.0') `%||%` = function(x, y) if (is.null(x)) y else x
 
 output_md = function() getOption('bookdown.output.markdown', FALSE)
 
