@@ -9,7 +9,9 @@ gitbook.require(["gitbook", "jQuery"], function(gitbook, $) {
 
     // the page.change event is thrown twice: before and after the page changes
     if (clipboard) {
-      // clipboard is already defined
+      // clipboard is already defined but we are on the same page
+      if (clipboard._prevPage === window.location.pathname) return;
+      // clipboard is already defined and url path change
       // we can deduct that we are before page changes
       clipboard.destroy(); // destroy the previous events listeners
       clipboard = undefined; // reset the clipboard object
@@ -24,6 +26,8 @@ gitbook.require(["gitbook", "jQuery"], function(gitbook, $) {
       }
     });
 
+    clipboard._prevPage = window.location.pathname
+
   });
 
 });
